/**
 * Copyright (C) The Apache Software Foundation. All rights reserved.
 *
 * This software is published under the terms of the Apache Software
 * License version 1.1, a copy of which has been included with this
 * distribution in the LICENSE.APL file.  */
package org.apache.log4j.ext;

/**
 * Title: SysUpTimeResolver<br>
 * Description: A class implementing this interface must provide a way of returning the system "up time",
 * in milliseconds. For example, you might have a class the uses a JNI call to an operating system
 * API to determine the real "up time" of the host machine.  You would specify the FQN of your
 * implmenting class in your properties file.  The SNMPTrapAppender includes a default implementation
 * of this interface that simply calls System.currentTimeMillis() to set the time.<br>
 * @author Thomas Muller (<a href="mailto:ttm@online.no">ttm@online.no</a>)
 * @author Mark Masterson (<a href="mailto:m.masterson@computer.org">m.masterson@computer.org</a>)<br>
 * <a href="http://www.m2technologies.net/">http://www.m2technologies.net/</a><br>
 * @version 1.0<br>
 */
public interface SysUpTimeResolver {
    /**
     * Implements a mechanism to return a "system up-time" that is relevant and meaningful
     * for a given application.
     * @return a milliseconds value as a long.
     */
    public long getSysUpTime();
}
